==> ocg_location-0.0.1.tar.gz: lib/screens/location_search_screen.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_location/blocs/location_detail.dart';
import 'package:ocg_location/blocs/location_search.dart';
import 'package:ocg_location/models/location_response.dart';
import 'package:ocg_location/screens/location_picker_screen.dart';
import 'package:ocg_location/widgets/location_search_widget.dart';
import 'package:ocg_location/widgets/search_input_widget.dart';

class LocationSearchScreen extends StatefulWidget {
  final LocationResponse selectedLocation;

  const LocationSearchScreen({Key key, this.selectedLocation})
      : super(key: key);
  @override
  State<StatefulWidget> createState() => _LocationSearchScreenState();
}

class _LocationSearchScreenState extends State<LocationSearchScreen> {
  String query = '';
  TextEditingController controller;
  LocationResponse selected;

  @override
  void initState() {
    super.initState();
    controller = TextEditingController();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        title: Text(
          "Location Search",
        ),
      ),
      body: BlocListener<LocationDetailBloc, LocationDetailState>(
        listener: (context, locationDetailState) {
          if (locationDetailState is LocationDetailLoadedState) {
            setState(() {
              selected = locationDetailState.location;
            });
          }
        },
        child: BlocBuilder<LocationSearchBloc, LocationSearchState>(
            builder: (context, locationSearchState) {
          return BlocBuilder<LocationDetailBloc, LocationDetailState>(
              builder: (context, locationDetailState) {
            return ModalProgressHUD(
              inAsyncCall: locationDetailState is LocationDetailLoadingState,
              child: SingleChildScrollView(
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: <Widget>[
                    SearchInputWidget(
                      onChanged: (val) {
                        setState(() {
                          this.query = val;
                        });
                      },
                      controller: controller,
                      label: "Search Location",
                    ),
                    ListTile(
                      leading: Icon(
                        Icons.check_circle,
                      ),
                      title: Text(
                        "${selected?.fullAddress ?? "Searching..."}",
                      ),
                      onTap: () async {},
                    ),
                    Divider(),
                    ListTile(
                      leading: Icon(
                        Icons.location_on,
                      ),
                      title: Text(
                        "Pick Location",
                      ),
                      trailing: Icon(
                        Icons.chevron_right,
                      ),
                      onTap: () async {
                        LocationResponse request = await Navigator.of(context)
                            .push(MaterialPageRoute(builder: (context) {
                          return LocationPickerScreen();
                        }));
                        if (request != null) {
                          Navigator.of(context).pop(request);
                        }
                      },
                    ),
                    LocationSearch(
                      query: query,
                      onLocationSelected: (query) async {
                        BlocProvider.of<LocationDetailBloc>(context)
                            .add(LocationDetailPlaceEvent(query.placeId));
                      },
                    ),
                  ],
                ),
              ),
            );
          });
        }),
      ),
      floatingActionButton: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 18),
        child: RoundedButton(
          "Continue",
          onTap: () {
            Navigator.of(context).pop(selected);
          },
          borderRadius: 12,
          padding: EdgeInsets.symmetric(horizontal: 12, vertical: 16),
        ),
      ),
      floatingActionButtonLocation: FloatingActionButtonLocation.centerFloat,
    );
  }
}

==> ocg_location-0.0.3.tar.gz: lib/screens/location_search_screen.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_location/blocs/location_detail.dart';
import 'package:ocg_location/blocs/location_search.dart';
import 'package:ocg_location/models/location_response.dart';
import 'package:ocg_location/screens/location_picker_screen.dart';
import 'package:ocg_location/widgets/location_search_widget.dart';
import 'package:ocg_location/widgets/search_input_widget.dart';

class LocationSearchScreen extends StatefulWidget {
  final bool isMapEnabled;
  const LocationSearchScreen({Key key, this.isMapEnabled = false})
      : super(key: key);
  @override
  State<StatefulWidget> createState() => _LocationSearchScreenState();
}

class _LocationSearchScreenState extends State<LocationSearchScreen> {
  String query = '';
  TextEditingController controller;
  LocationResponse selected;

  @override
  void initState() {
    super.initState();
    controller = TextEditingController();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        title: Text(
          "Location Search",
        ),
      ),
      body: BlocListener<LocationDetailBloc, LocationDetailState>(
        listener: (context, locationDetailState) {
          if (locationDetailState is LocationDetailLoadedState) {
            setState(() {
              selected = locationDetailState.location;
            });
          }
        },
        child: BlocBuilder<LocationSearchBloc, LocationSearchState>(
            builder: (context, locationSearchState) {
          return BlocBuilder<LocationDetailBloc, LocationDetailState>(
              builder: (context, locationDetailState) {
            return ModalProgressHUD(
              inAsyncCall: locationDetailState is LocationDetailLoadingState,
              child: SingleChildScrollView(
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: <Widget>[
                    SearchInputWidget(
                      onChanged: (val) {
                        setState(() {
                          this.query = val;
                        });
                      },
                      controller: controller,
                      label: "Search Location",
                    ),
                    ListTile(
                      leading: Icon(
                        selected?.fullAddress != null
                            ? Icons.location_on
                            : Icons.error,
                      ),
                      title: Text(
                        "${selected?.fullAddress ?? "Not Selected"}",
                      ),
                      onTap: null,
                    ),
                    Divider(),
                    widget.isMapEnabled
                        ? ListTile(
                            leading: Icon(
                              Icons.location_on,
                            ),
                            title: Text(
                              "Pick Location",
                            ),
                            trailing: Icon(
                              Icons.chevron_right,
                            ),
                            onTap: () async {
                              LocationResponse request =
                                  await Navigator.of(context).push(
                                      MaterialPageRoute(builder: (context) {
                                return LocationPickerScreen();
                              }));
                              if (request != null) {
                                Navigator.of(context).pop(request);
                              }
                            },
                          )
                        : Container(
                            width: 0,
                            height: 0,
                          ),
                    LocationSearch(
                      query: query,
                      onLocationSelected: (query) async {
                        BlocProvider.of<LocationDetailBloc>(context)
                            .add(LocationDetailPlaceEvent(query.placeId));
                      },
                    ),
                  ],
                ),
              ),
            );
          });
        }),
      ),
      floatingActionButton: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 18),
        child: RoundedButton(
          "Continue",
          onTap: selected == null
              ? null
              : () {
                  Navigator.of(context).pop(selected);
                },
          borderRadius: 12,
          padding: EdgeInsets.symmetric(horizontal: 12, vertical: 16),
        ),
      ),
      floatingActionButtonLocation: FloatingActionButtonLocation.centerFloat,
    );
  }
}
